<?php

/**
 * Menu callback to display an entity.
 *
 * As we load the entity for display, we're responsible for invoking a number
 * of hooks in their proper order.
 *
 * @see hook_entity_prepare_view()
 * @see hook_entity_view()
 * @see hook_entity_view_alter()
 */
function inbound_contact_view($entity, $view_mode = 'tweaky') {
    //print_r($entity);
    // Our entity type, for convenience.
    //die('test');
    $entity_type = 'inbound_contact';
    // Start setting up the content.
    $entity->content = array(
        '#view_mode' => $view_mode,
    );

    $entity->content['edit'] = array(
        '#type' => 'item',
        '#title' => t('Options'),
        '#markup' => l('Edit', 'admin/inbound/contact/'.$entity->id.'/edit'),
    );
    $entity->content['created'] = array(
        '#type' => 'item',
        '#title' => t('Created date'),
        '#markup' => format_date($entity->created),
    );
    $entity->content['email'] = array(
        '#type' => 'item',
        '#title' => t('E-Mail'),
        '#markup' => $entity->email,
    );

    $entity->content['firstname'] = array(
        '#type' => 'item',
        '#title' => t('First Name'),
        '#markup' => $entity->firstname,
    );
    $entity->content['lastname'] = array(
        '#type' => 'item',
        '#title' => t('Last Name'),
        '#markup' => $entity->lastname,
    );

    $entity->content['company_name'] = array(
        '#type' => 'item',
        '#title' => t('Company'),
        '#markup' => $entity->company_name,
    );

    $entity->content['persona'] = array(
        '#type' => 'item',
        '#title' => t('Persona'),
        '#markup' => $entity->persona,
    );

    /*
    $entity->content['lifecycle_stage'] = array(
        '#type' => 'item',
        '#title' => t('lifecycle_stage'),
        '#markup' => $entity->lifecycle_stage,
    );
    */


    $hits = inbound_session_hit_api_find(array('contact_id'=>$entity->id));
    foreach ($hits as $hit) {
        //debug_raw($hit);
        $events[] = array(
            'data' => array(
                'event_type' => '<span class="inbound_pageview">'.$hit->event.'</span>',
                'session_id' => '<span class="inbound_pageview" style="background-color: '.toColor($hit->session_id).'">'.$hit->session_id.'</span>',
                'date' => date('d.M.Y H:i:s', $hit->created),
                'link' => l($hit->event_label, $hit->event_value)
            ),
        );
    }

    $entity->content['events'] = array(
        '#theme' => 'table',
        '#header' => array(t('Type'), t('Session ID'), 'Timestamp', ''),
        '#rows' => $events,
    );


    $sessions = inbound_session_api_find(array('contact_id'=>$entity->id));
    //debug_raw($sessions);
    foreach ($sessions as $session) {
        // Create tabular rows for our entities.

        $datas = (array) json_decode($session->session_data);
        /*
        $output = '';

        $output .= 'IP '.$datas['ip'].'<br>';
        $output .= 'City/Country '.$datas['ip_data']->city.', '.$datas['ip_data']->country.'<br>';
        $output .= 'Org '.$datas['ip_data']->org.', '.$datas['ip_data']->as.'<br>';
        //$output .= print_r($datas['ip_data'],1).'<br>';
        $output .= 'Referrer: '.$datas['referrer'].'<br>';
        $output .= $datas['agent'].'<br>';
        $hits_list .= 'New Session<br>';
        $datas['hits'] = array_reverse($datas['hits']);
        foreach ($datas['hits'] as $data) {
            $output .= date('d.M.Y H:i:s', $data->timestamp).' '.l($data->title, $data->path).'<br>';
            //$hits_list .= date('d.M.Y H:i:s', $data->timestamp).' '.l($data->title, $data->path).'<br>';
        }
        $hits = inbound_session_hit_api_find(array('session_id'=>$entity->id));
        */
        //debug_raw($datas['agent']);


        $rows[] = array(
            'data' => array(
                'id' => $session->basic_id,
                'referrer' => $session->referrer.'<br>'.$session->landing_page.'<br>'.$session->exit_page,
                'session_type' => $session->session_type,
                'bundle' => $session->bundle_type,
                'session_data' => $output,
                'delete' => l('Edit', 'admin/inbound/session/'.$session->id.'/edit')
            ),
        );
    }



    // Put our entities into a themed table. See theme_table() for details.
    /*
    $entity->content['sessions'] = array(
        '#theme' => 'table',
        '#rows' => $rows,
        '#header' => array(t('ID'), 'Pages', t('Session Type'), t('Bundle'), t('Session Data'), 'Edit'),
    );


    $entity->content['raw'] = array(
        '#type' => 'item',
        '#title' => t('Raw Data'),
        '#markup' => '<pre>'.print_r($entity,1).'</pre>',
    );
    */

    // Now to invoke some hooks. We need the language code for
    // hook_entity_view(), so let's get that.
    global $language;
    $langcode = $language->language;
    // And now invoke hook_entity_view().
    //module_invoke_all('entity_view', $entity, $entity_type, $view_mode, $langcode);
    // Now invoke hook_entity_view_alter().
    //drupal_alter(array('inbound_contact_view', 'entity_view'), $entity->content, $entity_type);

    // And finally return the content.

    //return $entity->content;
    return theme('contact_detail', array(
        'created'=>format_date($entity->created),
        'comment_form'=>drupal_render(drupal_get_form('inbound_contact_comment_form', $entity)),
        'timeline'=>drupal_render($entity->content['events']),
        'content'=>drupal_render($entity->content)
    ));
}

function toColor($n) {
    return("#".substr("000000".dechex($n),-6));
}