<?php


/**
 * Returns a render array with all entity_example_basic entities.
 *
 * In this basic example we know that there won't be many entities,
 * so we'll just load them all for display. See pager_example.module
 * to implement a pager. Most implementations would probably do this
 * with the contrib Entity API module, or a view using views module,
 * but we avoid using non-core features in the Examples project.
 *
 * @see pager_example.module
 */

/**
 * Basic information for the page.
 */
function inbound_session_info_page() {

    $content = inbound_session_yeargraph();
    $content .= inbound_session_list_entities();

    return $content;
}

function inbound_session_list_entities() {

    $content = array();
    // Load all of our entities.

    if ($_SESSION['inbound']['session_filter']['date'] == '') {
        $_SESSION['inbound']['session_filter']['date'] = date('d.m.Y');
    }

    $_SESSION['inbound']['session_filter']['limit'] = 100;

    $entities = inbound_session_api_find($_SESSION['inbound']['session_filter']);
    if (!empty($entities)) {
        foreach ($entities as $entity) {
            // Create tabular rows for our entities.

            $output = '';
            $datas = (array) json_decode($entity->session_data);
            $output .= 'IP '.$datas['ip'].'<br>';
            $output .= 'City/Country '.$datas['ip_data']->city.', '.$datas['ip_data']->country.'<br>';
            $output .= 'Org '.$datas['ip_data']->org.', '.$datas['ip_data']->as.'<br>';
            //$output .= print_r($datas['ip_data'],1).'<br>';
            $output .= 'Referrer: '.$datas['referrer'].'<br>';
            $output .= $datas['agent'].'<br>';
            $output .= 'Last Update: '.format_date($entity->updated, 'custom', 'd-m-Y H:i').'<br>';



            $rows[] = array(
                'data' => array(
                    'id' => $entity->id,
                    'contact_id' => l($entity->contact_id, 'admin/inbound/contact/'.$entity->contact_id),
                    'email' => $entity->email,
                    'session_type' => $entity->session_type,
                    'bundle' => $entity->bundle_type,
                    'hits'=>inbound_session_hit_api_find(array('session_id'=>$entity->id, 'returncount'=>true)),
                    //'hits_old'=>$hits_old,
                    'session_data' => $output,
                    'delete' => l('Edit', 'admin/inbound/session/'.$entity->id.'/edit')
                ),
            );
        }
        // Put our entities into a themed table. See theme_table() for details.
        $content['entity_table'] = array(
            '#theme' => 'table',
            '#rows' => $rows,
            '#header' => array(t('ID'), t('Contact ID'), t('E-Mail'), t('Session Type'), t('Bundle'), t('Hits'), t('Session Data'), 'Edit'),
        );
    }
    else {
        // There were no entities. Tell the user.
        $content[] = array(
            '#type' => 'item',
            '#markup' => t('No sessions found.'),
        );
    }
    $head = 'Anzahl Sessions: '.count($rows);

    return drupal_render(drupal_get_form('inbound_session_filter_form')).$head.drupal_render($content);//'test';//$content;
}

function inbound_session_filter_form() {
    $form['session_type'] = array(
        '#type' => 'select',
        '#title' => t('Session Type'),
        '#options' => array(
            'all' => 'all',
            '0' => 'Undef',
            '1' => 'Humans',
            '2' => 'Bots'
        ),
        '#default_value' => $_SESSION['inbound']['session_filter']['session_type']
    );

    $options['all'] = 'all';
    $years = array(2015, 2016);
    foreach ($years as $year) {
        $months = array(0,1,2,3,4,5,6,7,8,9,10,11);
        foreach ($months as $month) {
            $days = array(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31);
            foreach ($days as $day) {
                $date = $day.'.'.($month+1).'.'.$year;
                $options[$date] = $date;
            }
        }
    }
    $form['date'] = array(
        '#type' => 'select',
        '#title' => t('Date'),
        '#options' => $options,
        '#default_value' => $_SESSION['inbound']['session_filter']['date']
    );
    $form['submit'] = array('#type' => 'submit', '#value' => t('Filter'));
    return $form;
}

function inbound_session_filter_form_submit($form, &$form_state) {
    if ($form_state['values']['session_type'] == 'all') {
        unset($_SESSION['inbound']['session_filter']['session_type']);
    } else {
        $_SESSION['inbound']['session_filter']['session_type'] = $form_state['values']['session_type'];
    }
    if ($form_state['values']['date'] == 'all') {
        unset($_SESSION['inbound']['session_filter']['date']);
        unset($_SESSION['inbound']['session_filter']['from']);
        unset($_SESSION['inbound']['session_filter']['to']);
    } else {
        $_SESSION['inbound']['session_filter']['date'] = $form_state['values']['date'];
        $_SESSION['inbound']['session_filter']['from'] = strtotime($form_state['values']['date']);
        $_SESSION['inbound']['session_filter']['to'] = strtotime($form_state['values']['date'])+3600*24;
    }
}

function inbound_session_yeargraph($year = 2016) {

    $years = array(2016);
    foreach ($years as $year) {
        $months = array(0,1,2,3,4,5,6,7,8,9,10,11);
        foreach ($months as $month) {
            $days = array(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31);
            foreach ($days as $day) {
                // Previous month
                $previous_month_params = array('from'=>mktime(0, 0, 0, $month, $day-1, $year),
                    'to'=>mktime(0, 0, 0, $month, $day, $year),
                    'session_type'=>1);
                $count = count(inbound_session_api_find($previous_month_params));

                // prepare data array
                $data .= "[new Date($year, ".($month-1).", $day), $count],\n";
            }
        }
    }


    $output .= "<script type=\"text/javascript\" src=\"https://www.google.com/jsapi?autoload={
'modules':[{
    'name':'visualization',
    'version':'1.1',
    'packages':['corechart', 'line', 'calendar']
}]
}\"></script>

<script type=\"text/javascript\">
        google.setOnLoadCallback(drawChart);

function drawChart() {

    var dataTable = new google.visualization.DataTable();

    dataTable.addColumn({ type: 'date', id: 'Date' });
    dataTable.addColumn({ type: 'number', id: 'Won/Loss' });
    dataTable.addRows([".$data."]);
    var options = {
         title: 'Sessions',
         height: 350,
    };

    var chart = new google.visualization.Calendar(document.getElementById('chart'));

    chart.draw(dataTable, options);
}
</script>";

    $output .= '<div id="chart" style="width: 1000px; height: 350px"></div></div>';
    $output .= '</div>';

    return $output;
}